#!/usr/bin/env python3
##############################################################################
# The MIT License (MIT)
#
# Copyright (c) 2016 Hajime Nakagami
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
##############################################################################
import unittest
import io
import csvsqlite3


class TestCsvDb(unittest.TestCase):
    def test_basic_csv(self):
        conn = csvsqlite3.connect(io.StringIO(
"""aaa,bbb,ccc
1,2,3
a,b,c
A,B,C
"""))
        cur = conn.cursor()
        cur.execute('select ccc,aaa from csv')
        self.assertEqual(
            [d[0] for d in cur.description],
            ['ccc', 'aaa']
        )
        self.assertEqual(
            cur.fetchall(),
            [('3','1'),('c','a'),('C','A')]
        )

    def test_null_blank_csv(self):
        conn = csvsqlite3.connect(io.StringIO(
"""aaa,bbb,ccc
1,2,
a,,c
A,
,

x
"""))
        cur = conn.cursor()
        cur.execute('select * from csv')
        self.assertEqual(
            cur.fetchall(),
            [('1','2', ''),('a','', 'c'),('A','', None),('','', None),(None, None, None),('x', None, None)]
        )

if __name__ == "__main__":
    unittest.main()
